package net.jieyuu.controller;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import net.jieyuu.enums.BizCodeEnum;
import net.jieyuu.request.AddressAddRequest;
import net.jieyuu.service.AddressService;
import net.jieyuu.utils.JsonData;
import net.jieyuu.vo.AddressVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 电商-公司收发货地址表 前端控制器
 * </p>
 *
 * @author jieyuu
 * @since 2024-02-12
 */
@Api(tags = "收货地址模块")
@RestController
@RequestMapping("/api/address/v1/")
public class AddressController {

    @Autowired
    AddressService addressService;

    @ApiOperation("根据id查询地址详情")
    @GetMapping("find/{address_id}")
    public JsonData detail(
            @ApiParam(value = "地址", required = true)
            @PathVariable("address_id") long id) {
        AddressVO addressVO = addressService.detail(id);
        return addressVO == null ? JsonData.buildResult(BizCodeEnum.ADDRESS_NO_EXITS) : JsonData.buildSuccess(addressVO);
    }


    @ApiOperation("新增收货地址")
    @PostMapping("add")
    public JsonData add(@ApiParam("地址对象")
                        @RequestBody AddressAddRequest addressAddRequest) {
        addressService.add(addressAddRequest);
        return JsonData.buildSuccess();
    }

    @ApiOperation("删除指定的收货地址")
    @GetMapping("del/{address_id}")
    public JsonData del(
            @ApiParam(value = "地址", required = true)
            @PathVariable("address_id") long id) {
        int row = addressService.del(id);

        return row == 1 ? JsonData.buildSuccess() : JsonData.buildResult(BizCodeEnum.ADDRESS_DEL_FAIL);
    }


    @ApiOperation("查询用户全部收货地址")
    @GetMapping("/list")
    public JsonData findUserAllAddress(){
        List<AddressVO> list= addressService.listUserAllAddress();
        return JsonData.buildSuccess(list);
    }


}

